@@ -4,15 +4,16 @@ use strict;
 use warnings;
 no warnings;
 
-use Exporter qw(import);
+use base qw(Exporter);
+use vars qw(@EXPORT_OK @EXPORT $VERSION);
 
 use Carp qw(carp);
 use File::Spec::Functions qw(catfile);
 
-our @EXPORT    = qw(run_t_manifest);
-our @EXPORT_OK = qw(get_t_files make_test_manifest manifest_name);
+@EXPORT    = qw(run_t_manifest);
+@EXPORT_OK = qw(get_t_files make_test_manifest manifest_name);
 
-our $VERSION = '2.02_01';
+$VERSION = '2.01';
 
 my %SeenInclude = ();
 my %SeenTest = ();
@@ -27,8 +28,6 @@ sub MY::test_via_harness {
 		   qq|'\$(INST_ARCHLIB)', \$(TEST_LEVEL) )"\n|;
 	};
 
-=encoding utf8
-
 =head1 NAME
 
 Test::Manifest - interact with a t/test_manifest file
@@ -40,7 +39,7 @@ Test::Manifest - interact with a t/test_manifest file
 
 	# in Build.PL
 	my $class = do {
-		if( eval 'use Test::Manifest 2.00; 1' ) {
+		if( eval "Test::Manifest 2.00" ) {
 			Test::Manifest->get_module_build_subclass;
 			}
 		else {
@@ -79,9 +78,9 @@ files to run and it will issue a warning.
 Optionally, you can add a number after the test name in test_manifest
 to define sets of tests. See C<get_t_files> for more information.
 
-=head2 ExtUtils::MakeMaker
+=head2 ExtUtils::Makemaker
 
-To override the test order behaviour in C<MakeMaker>, C<Test::Manifest>
+To override the test order behaviour in C<Makemaker>, C<Test::Manifest>
 inserts itself in the C<test_via_harness> step by providing its own
 test runner. In C<Makefile.PL>, all you have to do is load C<Test::Manifest>
 before you call C<WriteMakefile>. To make it optional, load it in an eval:
@@ -96,7 +95,7 @@ can load C<Test::Manifest> (version 2.00 or later), C<Test::Manifest> can
 create the subclass for you.
 
 	my $class = do {
-		if( eval 'use Test::Manifest 2.00; 1' ) {
+		if( eval 'Test::Manifest 2.00; 1' ) {
 			Test::Manifest->get_module_build_subclass;
 			}
 		else {
@@ -111,7 +110,7 @@ This is a bit of a problem when you already have your own subclass.
 C<Test::Manifest> overrides C<find_test_files>, so you can get just
 that code to add to your own subclass code string:
 
-	my $code = eval 'use Test::Manifest 2.00; 1'
+	my $code = eval 'Test::Manifest 2.00; 1'
 			?
 		Test::Manifest->get_module_build_code_string
 			:
@@ -195,7 +194,7 @@ sub get_module_build_code_string {
 
 =item run_t_manifest( TEST_VERBOSE, INST_LIB, INST_ARCHLIB, TEST_LEVEL )
 
-For C<MakeMaker> only. You don't have to mess with this at the user
+For C<Makemaker> only. You don't have to mess with this at the user
 level.
 
 Run all of the files in F<t/test_manifest> through C<Test::Harness:runtests>
@@ -273,7 +272,7 @@ filenames up to the C<;unskip> directive (or end of file):
 	;unskip
 	run_this2
 
-To select sets of tests, specify the level in the environment variable
+To select sets of tests, specify the level in the enviroment variable
 C<TEST_LEVEL>:
 
 	make test # run all tests no matter the level
@@ -315,7 +314,7 @@ sub _load_test_manifest {
 
 		next unless $_;
 
-		my( $command, $arg ) = split /\s+/, $_, 2;
+		my( $command, $arg ) = split/\s+/, $_, 2;
 		if( ';' eq substr( $command, 0, 1 ) ) {
 			if( $command eq ';include' ) {
 				my $result = _include_file( $arg, $., $upper_bound );
@@ -341,10 +340,9 @@ sub _load_test_manifest {
 			unless $level =~ m/^\d+(?:.\d+)?$/;
 		carp( "test file begins with t/ [$test]" ) if m|^t/|;
 
-		if( -e catfile( "t", $test ) ) {
-			$test = catfile( "t", $test )
-			}
-		else {
+		$test = catfile( "t", $test ) if -e catfile( "t", $test );
+
+		unless( -e $test ) {
 			carp( "test file [$test] does not exist! Skipping!" );
 			next;
 			}
@@ -437,15 +435,13 @@ This source is in Github:
 Matt Vanderpol suggested and supplied a patch for the C<;include>
 feature.
 
-Olivier MenguE<eacute> supplied a documentation patch.
-
 =head1 AUTHOR
 
 brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2002-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2002-2014 brian d foy. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
